﻿using System.Collections.Generic;

using DevExpress.XtraTreeList;

namespace TestProject
{
    /// <summary>
    /// 노드
    /// </summary>
    public class Node : TreeList.IVirtualTreeListData
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 부모
        /// </summary>
        private Node parent;

        /// <summary>
        /// 자식 리스트
        /// </summary>
        private List<Node> childList = new List<Node>();

        /// <summary>
        /// 셀 배열
        /// </summary>
        private object[] cellArray;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - Node(parent, cellArray)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="parent">부모</param>
        /// <param name="cellArray">셀 배열</param>
        public Node(Node parent, object[] cellArray)
        {
            this.parent    = parent;
            this.cellArray = cellArray;

            if(this.parent != null)
            {
                this.parent.childList.Add(this);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 가상 트리 자식 노드들 구하기 - VirtualTreeGetChildNodes(info)

        /// <summary>
        /// 가상 트리 자식 노드들 구하기
        /// </summary>
        /// <param name="info">정보</param>
        void TreeList.IVirtualTreeListData.VirtualTreeGetChildNodes(VirtualTreeGetChildNodesInfo info)
        {
            info.Children = this.childList;
        }

        #endregion
        #region 가상 트리 셀 값 구하기 - VirtualTreeGetCellValue(info)

        /// <summary>
        /// 가상 트리 셀 값 구하기
        /// </summary>
        /// <param name="info"></param>
        void TreeList.IVirtualTreeListData.VirtualTreeGetCellValue(VirtualTreeGetCellValueInfo info)
        {
            info.CellData = this.cellArray[info.Column.AbsoluteIndex];
        }

        #endregion
        #region 가상 트리 셀 값 설정하기 - VirtualTreeSetCellValue(info)

        /// <summary>
        /// 가상 트리 셀 값 설정하기
        /// </summary>
        /// <param name="info"></param>
        void TreeList.IVirtualTreeListData.VirtualTreeSetCellValue(VirtualTreeSetCellValueInfo info)
        {
            this.cellArray[info.Column.AbsoluteIndex] = info.NewCellData;
        }

        #endregion
    }
}